@@ -31,8 +31,8 @@ Usage:
  This functionality works similarly to the normal percentage compare.
  The first argument of the focused percentage match is the center coordinate of the comparison area.
  ------
- $ monkey_vision -fm "(XX, YY)" imagePath1 imagePath2 ... imagePathN
- $ monkey_vision --focusedMatch "(XX, YY)" imagePath1 imagePath2 ... imagePathN
+ $ monkey_vision -fm XX YY imagePath1 imagePath2 ... imagePathN
+ $ monkey_vision --focusedMatch XX YY imagePath1 imagePath2 ... imagePathN
 
 """
 
@@ -66,7 +66,9 @@ def main():
         return event_points
 
     if run_monkey_focused_compare:
-        percentage_match = focused_percentage_compare(args[0], *args[1:])
+        percentage_match = focused_percentage_compare(
+            len(args[0]), len(args[1]), *args[2:]
+        )
         print(percentage_match)
         return percentage_match
 
