@@ -1,11 +1,10 @@
 import cv2
 
 
-def imcrop(imagePath, center):
+def imcrop(imagePath, x, y):
     """
     Method to crop the an image specified in the imagePath around the center specified in the function arguments.
     """
-    (x, y) = (int(x) for x in center[1:-1].split(","))
     area = 100  # width and height in pixels around the center.
     image = cv2.imread(imagePath)
     height, width, channels = image.shape
